@@ -9,12 +9,13 @@ import click
 from ....env_mgr.kbenv import KBEnvManager
 from ... import options
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 
 
-@click.command('run', short_help='run kubectl',
-               context_settings={'ignore_unknown_options': True})
-@click.argument('args', metavar='<args>', nargs=-1, required=True)
+@click.command(
+    "run", short_help="run kubectl", context_settings={"ignore_unknown_options": True}
+)
+@click.argument("args", metavar="<args>", nargs=-1, required=True)
 @options.debug
 @options.no_color
 @options.verbose
