@@ -15,21 +15,17 @@ import awacs.states
 import awacs.sts
 from awacs.aws import Action, Allow, Policy, PolicyDocument, Principal, Statement
 from awacs.helpers.trust import make_simple_assume_policy
-from troposphere import (  # noqa pylint: disable=unused-import
+from troposphere import (
     AccountId,
     Join,
     NoValue,
     Output,
     Partition,
-    Region,
     StackName,
-    Sub,
     awslambda,
     cloudfront,
     iam,
-    logs,
     s3,
-    stepfunctions,
 )
 
 from runway.cfngin.blueprints.base import Blueprint
@@ -372,9 +368,6 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
                     ]
                 ),
                 VersioningConfiguration=s3.VersioningConfiguration(Status="Enabled"),
-                WebsiteConfiguration=s3.WebsiteConfiguration(
-                    IndexDocument="index.html", ErrorDocument="error.html"
-                ),
             )
         )
         self.template.add_output(
@@ -384,6 +377,10 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
         )
 
         if not self.cf_enabled:
+            # bucket cannot be configured with WebsiteConfiguration when using OAI S3Origin
+            bucket["WebsiteConfiguration"] = s3.WebsiteConfiguration(
+                IndexDocument="index.html", ErrorDocument="error.html"
+            )
             self.template.add_output(
                 Output(
                     "BucketWebsiteURL",
@@ -608,6 +605,7 @@ class StaticSite(Blueprint):  # pylint: disable=too-few-public-methods
             Statement(
                 Action=[awacs.s3.GetObject],
                 Effect=Allow,
+                # S3CanonicalUserId is translated to the ARN when AWS renders this
                 Principal=Principal("CanonicalUser", oai.get_att("S3CanonicalUserId")),
                 Resource=[Join("", [bucket.get_att("Arn"), "/*"])],
             )
