@@ -1,4 +1,3 @@
-
 """Check the authorization information passed along via the cookie headers.
 
 When the information is not present or an error occurs due to verification a new
@@ -33,7 +32,9 @@ from shared import (  # noqa pylint: disable=import-error
 
 LOGGER = logging.getLogger(__file__)
 
-SECRET_ALLOWED_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~"
+SECRET_ALLOWED_CHARS = (
+    "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~"
+)
 NONCE_LENGTH = 16
 PKCE_LENGTH = 43
 CONFIG = get_config()
@@ -47,24 +48,19 @@ def handler(event, _context):
         _context (Any): Lambda context object.
 
     """
-    request = event['Records'][0]['cf']['request']
-    domain_name = request['headers']['host'][0]['value']
-    querystring = request.get('querystring')
-    request_query_string = (
-        "?%s" % querystring
-    ) if querystring else ""
-    requested_uri = '%s%s' % (request['uri'], request_query_string)
+    request = event["Records"][0]["cf"]["request"]
+    domain_name = request["headers"]["host"][0]["value"]
+    querystring = request.get("querystring")
+    request_query_string = ("?%s" % querystring) if querystring else ""
+    requested_uri = "%s%s" % (request["uri"], request_query_string)
     nonce = generate_nonce()
 
     try:
         # Extract the cookies received from Cognito
-        extracted = extract_and_parse_cookies(
-            request['headers'],
-            CONFIG['client_id']
-        )
-        token_user_name = extracted.get('tokenUserName')
-        id_token = extracted.get('idToken')
-        refresh_token = extracted.get('refreshToken')
+        extracted = extract_and_parse_cookies(request["headers"], CONFIG["client_id"])
+        token_user_name = extracted.get("tokenUserName")
+        id_token = extracted.get("idToken")
+        refresh_token = extracted.get("refreshToken")
 
         # If the token user name or id token are missing then we need
         # new credentials
@@ -75,7 +71,7 @@ def handler(event, _context):
 
         # Get the expiration date from the id token.
         decoded_token = decode_token(id_token)
-        expiration = decoded_token.get('exp')
+        expiration = decoded_token.get("exp")
         exp_date = datetime.datetime.fromtimestamp(expiration)
         now = datetime.datetime.now()
 
@@ -84,98 +80,92 @@ def handler(event, _context):
         if now > (exp_date - datetime.timedelta(minutes=5)) and refresh_token:
             headers = {
                 # Redirect the user to the refresh agent
-                'location': [
+                "location": [
                     {
-                        'key': 'location',
-                        'value': 'https://%s%s?%s' % (
+                        "key": "location",
+                        "value": "https://%s%s?%s"
+                        % (
                             domain_name,
-                            CONFIG.get('redirect_path_auth_refresh'),
-                            urlencode({
-                                'requestedUri': requested_uri,
-                                'nonce': nonce
-                            })
-                        )
+                            CONFIG.get("redirect_path_auth_refresh"),
+                            urlencode({"requestedUri": requested_uri, "nonce": nonce}),
+                        ),
                     }
                 ],
-                'set-cookie': [
+                "set-cookie": [
                     # Set the Nonce Cookie
                     {
-                        'key': 'set-cookie',
-                        'value': 'spa-auth-edge-nonce=%s; %s' % (
+                        "key": "set-cookie",
+                        "value": "spa-auth-edge-nonce=%s; %s"
+                        % (
                             quote_plus(nonce),
-                            CONFIG.get('cookie_settings').get('nonce')
-                        )
+                            CONFIG.get("cookie_settings").get("nonce"),
+                        ),
                     }
-                ]
+                ],
             }
             # Add all CloudFrontHeaders
-            headers.update(CONFIG.get('cloud_front_headers'))
+            headers.update(CONFIG.get("cloud_front_headers"))
             return {
-                'status': '307',
-                'statusDescription': 'Temporary Redirect',
-                'headers': headers
+                "status": "307",
+                "statusDescription": "Temporary Redirect",
+                "headers": headers,
             }
 
         # Validate the token information against the Cognito JWKS
         validate_jwt(
             id_token,
-            CONFIG.get('token_jwks_uri'),
-            CONFIG.get('token_issuer'),
-            CONFIG.get('client_id'))
+            CONFIG.get("token_jwks_uri"),
+            CONFIG.get("token_issuer"),
+            CONFIG.get("client_id"),
+        )
 
         return request
     # We need new authorization. Get the user over to Cognito
-    except Exception: # noqa pylint: disable=broad-except
+    except Exception:  # noqa pylint: disable=broad-except
         pkce, pkce_hash = generate_pkce_verifier()
         payload = {
-            'redirect_uri': 'https://%s%s' % (domain_name, CONFIG['redirect_path_sign_in']),
-            'response_type': 'code',
-            'client_id': CONFIG["client_id"],
-            'state': base64.urlsafe_b64encode(
-                bytes(json.dumps({
-                    "nonce": nonce,
-                    "requestedUri": requested_uri
-                }).encode())
+            "redirect_uri": "https://%s%s"
+            % (domain_name, CONFIG["redirect_path_sign_in"]),
+            "response_type": "code",
+            "client_id": CONFIG["client_id"],
+            "state": base64.urlsafe_b64encode(
+                bytes(
+                    json.dumps({"nonce": nonce, "requestedUri": requested_uri}).encode()
+                )
             ),
-            'scope': " ".join(CONFIG['oauth_scopes']),
-            'code_challenge_method': "S256",
-            'code_challenge': pkce_hash
+            "scope": " ".join(CONFIG["oauth_scopes"]),
+            "code_challenge_method": "S256",
+            "code_challenge": pkce_hash,
         }
         login_query_string = urlencode(payload, quote_via=quote_plus)
-        headers = CONFIG.get('cloud_front_headers')
-        headers['location'] = [
+        headers = CONFIG.get("cloud_front_headers")
+        headers["location"] = [
             {
-                'key': 'location',
-                'value': 'https://%s/oauth2/authorize?%s' % (
-                    CONFIG['cognito_auth_domain'],
-                    login_query_string
-                )
+                "key": "location",
+                "value": "https://%s/oauth2/authorize?%s"
+                % (CONFIG["cognito_auth_domain"], login_query_string),
             }
         ]
-        headers['set-cookie'] = [
+        headers["set-cookie"] = [
             # Set Nonce Cookie
             {
-                'key': 'set-cookie',
-                'value': 'spa-auth-edge-nonce=%s; %s' % (
-                    quote_plus(nonce),
-                    CONFIG.get('cookie_settings', {}).get('nonce')
-                )
+                "key": "set-cookie",
+                "value": "spa-auth-edge-nonce=%s; %s"
+                % (quote_plus(nonce), CONFIG.get("cookie_settings", {}).get("nonce")),
             },
             # Set PKCE Cookie
             {
-                'key': 'set-cookie',
-                'value': 'spa-auth-edge-pkce=%s; %s' % (
-                    quote_plus(pkce),
-                    CONFIG.get('cookie_settings', {}).get('nonce')
-                )
+                "key": "set-cookie",
+                "value": "spa-auth-edge-pkce=%s; %s"
+                % (quote_plus(pkce), CONFIG.get("cookie_settings", {}).get("nonce")),
             },
         ]
 
         # Redirect user to the Cognito Login
         return {
-            'status': '307',
-            'statusDescription': 'Temporary Redirect',
-            'headers': headers
+            "status": "307",
+            "statusDescription": "Temporary Redirect",
+            "headers": headers,
         }
 
 
@@ -183,13 +173,13 @@ def generate_pkce_verifier():
     """Generate the PKCE verification code."""
     pkce = random_key(PKCE_LENGTH)
     pkce_hash = hashlib.sha256()
-    pkce_hash.update(pkce.encode('UTF-8'))
+    pkce_hash.update(pkce.encode("UTF-8"))
     pkce_hash = pkce_hash.digest()
     pkce_hash_b64 = base64.b64encode(pkce_hash)
     decoded_pkce = pkce_hash_b64.decode("UTF-8")
-    decoded_pkce = re.sub(r'\=', '', decoded_pkce)
-    decoded_pkce = re.sub(r'\+', '-', decoded_pkce)
-    decoded_pkce = re.sub(r'\/', '_', decoded_pkce)
+    decoded_pkce = re.sub(r"\=", "", decoded_pkce)
+    decoded_pkce = re.sub(r"\+", "-", decoded_pkce)
+    decoded_pkce = re.sub(r"\/", "_", decoded_pkce)
 
     return [pkce, decoded_pkce]
 
@@ -206,14 +196,10 @@ def random_key(length=15):
         length (int): The length of the random key.
 
     """
-    return ''.join(secrets.choice(SECRET_ALLOWED_CHARS) for _ in range(length))
+    return "".join(secrets.choice(SECRET_ALLOWED_CHARS) for _ in range(length))
 
 
-def validate_jwt(jwt_token,
-                 jwks_uri,
-                 issuer,
-                 audience
-                ):  # noqa: E124
+def validate_jwt(jwt_token, jwks_uri, issuer, audience):  # noqa: E124
     """Validate the JWT token against the Cognito JWKs.
 
     Args:
@@ -225,18 +211,19 @@ def validate_jwt(jwt_token,
     """
     token_headers = jwt.get_unverified_header(jwt_token)
     if not token_headers:
-        raise Exception('Cannot Parse JWT Token Headers')
+        raise Exception("Cannot Parse JWT Token Headers")
 
-    kid = token_headers.get('kid')
+    kid = token_headers.get("kid")
     jwk = get_signing_key(jwks_uri, kid)
 
     return jwt.decode(
         jwt_token,
         jwk,
-        algorithms=['RS256'],
+        algorithms=["RS256"],
         audience=audience,
         issuer=issuer,
-        options={'verify_at_hash': False})
+        options={"verify_at_hash": False},
+    )
 
 
 def is_rsa_signing_key(key):
@@ -257,6 +244,6 @@ def get_signing_key(jwks_uri, kid):
         kid (str): Key ID of the signing key we are looking for.
 
     """
-    client = JwksClient({'jwks_uri': jwks_uri})
+    client = JwksClient({"jwks_uri": jwks_uri})
     jwk = client.get_signing_key(kid)
-    return jwk.get('rsaPublicKey') if is_rsa_signing_key(jwk) else jwk.get('publicKey')
+    return jwk.get("rsaPublicKey") if is_rsa_signing_key(jwk) else jwk.get("publicKey")
