@@ -16,16 +16,14 @@ else:
 @pytest.fixture(scope="package")
 def cfngin_fixture_dir():
     """Path to the fixture directory."""
-    path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                        'fixtures')
+    path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "fixtures")
     return py.path.local(path)  # pylint: disable=no-member
 
 
 @pytest.fixture(scope="package")
 def cfngin_fixtures():
     """CFNgin fixture directory Path object."""
-    path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                        'fixtures')
+    path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "fixtures")
     return Path(path)
 
 
@@ -39,8 +37,5 @@ def empty_dag():
 def basic_dag():
     """Create a basic DAG."""
     dag = DAG()
-    dag.from_dict({'a': ['b', 'c'],
-                   'b': ['d'],
-                   'c': ['d'],
-                   'd': []})
+    dag.from_dict({"a": ["b", "c"], "b": ["d"], "c": ["d"], "d": []})
     return dag
